lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Message-ID: <20250327205355.378659-34-mingo@kernel.org>
Date: Thu, 27 Mar 2025 21:53:46 +0100
From: Ingo Molnar <mingo@...nel.org>
To: linux-kernel@...r.kernel.org
Cc: Juergen Gross <jgross@...e.com>,
	"H . Peter Anvin" <hpa@...or.com>,
	Linus Torvalds <torvalds@...ux-foundation.org>,
	Peter Zijlstra <peterz@...radead.org>,
	Borislav Petkov <bp@...en8.de>,
	Thomas Gleixner <tglx@...utronix.de>
Subject: [PATCH 33/41] x86/alternatives: Rename 'text_poke_int3_batch()' to 'text_poke_int3_batch_process()'

Make it clear in the name that this is the function that does
the actual batch processing (patching).

Signed-off-by: Ingo Molnar <mingo@...nel.org>
---
 arch/x86/kernel/alternative.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/arch/x86/kernel/alternative.c b/arch/x86/kernel/alternative.c
index 40e86b41bb86..6c3850527bd5 100644
--- a/arch/x86/kernel/alternative.c
+++ b/arch/x86/kernel/alternative.c
@@ -2462,7 +2462,7 @@ struct text_poke_int3_loc {
 	u8 len;
 	u8 opcode;
 	const u8 text[POKE_MAX_OPCODE_SIZE];
-	/* see text_poke_int3_batch() */
+	/* see text_poke_int3_batch_process() */
 	u8 old;
 };
 
@@ -2532,7 +2532,7 @@ noinstr int text_poke_int3_handler(struct pt_regs *regs)
 		return 0;
 
 	/*
 	 * Discount the INT3. See text_poke_int3_batch().
 	 */
 	ip = (void *) regs->ip - INT3_INSN_SIZE;
 
@@ -2590,7 +2590,7 @@ noinstr int text_poke_int3_handler(struct pt_regs *regs)
 }
 
 /**
  * text_poke_int3_batch() -- update instructions on live kernel on SMP
  * @tp_array.vec:		vector of instructions to patch
  * @tp_array.nr_entries:	number of entries in the vector
  *
@@ -2610,7 +2610,7 @@ noinstr int text_poke_int3_handler(struct pt_regs *regs)
  *		  replacing opcode
  *	- sync cores
  */
-static void text_poke_int3_batch(void)
+static void text_poke_int3_batch_process(void)
 {
 	unsigned char int3 = INT3_INSN_OPCODE;
 	unsigned int i;
@@ -2856,7 +2856,7 @@ static bool tp_addr_ordered(void *addr)
 void text_poke_int3_finish(void)
 {
 	if (tp_array.nr_entries) {
-		text_poke_int3_batch();
+		text_poke_int3_batch_process();
 		tp_array.nr_entries = 0;
 	}
 }
@@ -2866,7 +2866,7 @@ static void text_poke_int3_flush(void *addr)
 	lockdep_assert_held(&text_mutex);
 
 	if (tp_array.nr_entries == TP_ARRAY_NR_ENTRIES_MAX || !tp_addr_ordered(addr)) {
-		text_poke_int3_batch();
+		text_poke_int3_batch_process();
 		tp_array.nr_entries = 0;
 	}
 }
@@ -2532,7 +2532,7 @@ noinstr int text_poke_int3_handler(struct pt_regs *regs)
 
 	/*
-	 * Discount the INT3. See text_poke_int3_batch().
+	 * Discount the INT3. See text_poke_int3_batch_process().
 	 */
 	ip = (void *) regs->ip - INT3_INSN_SIZE;
@@ -2590,7 +2590,7 @@ noinstr int text_poke_int3_handler(struct pt_regs *regs)
 
 /**
- * text_poke_int3_batch() -- update instructions on live kernel on SMP
+ * text_poke_int3_batch_process() -- update instructions on live kernel on SMP
  * @tp_array.vec:		vector of instructions to patch
  * @tp_array.nr_entries:	number of entries in the vector
-- 
2.45.2


Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ